﻿Fluke Calibration                                           MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Tek MDO4000 Level Meas Unc VER VISA /EPM,SWPG
DATE:                  2018-03-14 12:45:22
AUTHOR:                Fluke Calibration
REVISION:              $Revision: 23095 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       3
NUMBER OF LINES:       101
CONFIGURATION:         Agilent EPM
CONFIGURATION:         Agilent E9304A on channel 1
CONFIGURATION:         Anritsu MG3694B
STANDARD:              Agilent 11667A
=============================================================================
#
#  Procedure Author:
#        CAD
#
#  Models covered:
#        MDO4014-3, MDO4034-3, MDO4054-3, MDO4054-6, MDO4104-3, MDO4104-6
#
#  Compatibility:
#        MET/CAL version 7.3.38 or later
#
#  Additional Equipment Required:
#        Cable, Type N (m)-(m), 50 Ω, 36", DC to 6 GHz
#        Cable, BNC (m)-(m), 50 Ω, 36", 10 MHz
#        Adapter, Type N (m)-(m), DC to 6 GHz
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# These statements are here to force the main procedure header to list the
# configuration required by the subprocedures.
  1.001  IF           0
  1.002  IEEE         [@SWPG]
  1.003  STD          Agilent 11667A
  1.004  ENDIF

  1.005  HEAD         -2 [V @Freq] @ [V @Level]
  1.006  MATH         @SWPG_Freq = @Freq; @SWPG_Ampl = @Level
  1.007  MATH         FreqHz = BASE(@Freq); Level_dBm = BASE(@Level)
  1.008  MATH         SpanHz = BASE(@Span)
  1.009  MATH         SplitterSWR = ACCV(@Splitter, "Output SWR", BASE(@Freq))
  1.010  MATH         MismatchPct = MISMATCHSWR(SplitterSWR, 1.5)
  1.011  MATH         EPM_Conf = CONF(INSTR("EPM"))

  1.012  JMPL         CONTINUE
  1.013  EVAL   Force connection message on Repeat/Cancel.
  2.001  CALL         Sub Output Off /SWPG
  2.002  MATH         @Connected = ""; @Time = ""
  2.003  CALL         Sub Tek MDO4000 Check and Display Connection
  2.004  LABEL        CONTINUE

  2.005  CALL         Sub Apply /SWPG
  2.006  TSET         TDESC = [V @Freq]
  2.007  VISA         RF:FREQUENCY [V FreqHz];SPAN [V SpanHz]
  2.008  VISA         RF:REFLEVEL [V Level_dBm]
  2.009  TARGET       -m
  2.010  VISA         ACQUIRE:STATE ON
  2.011  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA

  2.012  IF           @Abort
  2.013  END
  2.014  ENDIF

# Wait 500 ms for the DUT to locate peak marker amplitude.
  2.015  VISA         [D500]MARKER:REFERENCE:AMPLITUDE?[I]
  2.016  MATH         DUT_Meas = MEM

  2.017  EPM          PowerSensorA = E9304A; SourceSWR_A = [V SplitterSWR]
  2.017  EPM          ReadingRateA = Normal; AverageCountA = 32
  2.017  EPM          +PowerA = [V Level_dBm] dBm; @FreqA = [V FreqHz] Hz

  2.018  MATH         EPM_PowerLog = MEM; EPM_PowerLin = DBMTOW(MEM)
  2.019  MATH         EPM_RefAcc = REFACC()

# Power Meter uncertainty contribution in percent, normalized.
  2.020  MATH         EPM_AccPct = (EPM_RefAcc / EPM_PowerLin) * 100
  2.021  MATH         EPM_UncPct = EPM_AccPct / EPM_Conf
# RSS and expand.
  2.022  MATH         MeasUncPct = RSS2(EPM_UncPct, MismatchPct) * 2
  2.023  MATH         L[1] = PCTTODBW_D(MeasUncPct)
  2.024  ACC          0.00dB         L1U                                   +DW

  2.025  MATH         MEM = DUT_Meas - EPM_PowerLog
  2.026  MEMCX        0.00dB         1U

  3.001  END
